@@ -1,12 +1,12 @@
 package Bencher::Scenario::DigestSHA1;
 
-our $DATE = '2017-01-25'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-07-10'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 sub _create_file {
     my ($size) = @_;
@@ -46,9 +46,9 @@ our $scenario = {
 
         my $dss = $sc->{datasets};
         for my $ds (@$dss) {
-            $log->infof("Creating temporary file with size of %.1fMB ...", $ds->{_size}/1024/1024);
+            log_info("Creating temporary file with size of %.1fMB ...", $ds->{_size}/1024/1024);
             my $filename = _create_file($ds->{_size});
-            $log->infof("Created file %s", $filename);
+            log_info("Created file %s", $filename);
             $ds->{args}{filename} = $filename;
         }
     },
@@ -61,7 +61,7 @@ our $scenario = {
         for my $ds (@$dss) {
             my $filename = $ds->{args}{filename};
             next unless $filename;
-            $log->infof("Unlinking %s", $filename);
+            log_info("Unlinking %s", $filename);
             unlink $filename;
         }
     },
@@ -82,7 +82,7 @@ Bencher::Scenario::DigestSHA1 - Benchmark Digest::SHA1 against Digest::SHA
 
 =head1 VERSION
 
-This document describes version 0.002 of Bencher::Scenario::DigestSHA1 (from Perl distribution Bencher-Scenario-DigestSHA1), released on 2017-01-25.
+This document describes version 0.003 of Bencher::Scenario::DigestSHA1 (from Perl distribution Bencher-Scenario-DigestSHA1), released on 2017-07-10.
 
 =head1 SYNOPSIS
 
@@ -106,7 +106,7 @@ Version numbers shown below are the versions used when running the sample benchm
 
 L<Digest::SHA1> 2.13
 
-L<Digest::SHA> 5.95
+L<Digest::SHA> 5.96
 
 =head1 BENCHMARK PARTICIPANTS
 
@@ -140,29 +140,29 @@ Code template:
 
 =head1 SAMPLE BENCHMARK RESULTS
 
-Run on: perl: I<< v5.24.0 >>, CPU: I<< Intel(R) Core(TM) M-5Y71 CPU @ 1.20GHz (2 cores) >>, OS: I<< GNU/Linux LinuxMint version 17.3 >>, OS kernel: I<< Linux version 3.19.0-32-generic >>.
+Run on: perl: I<< v5.26.0 >>, CPU: I<< Intel(R) Core(TM) i5-2400 CPU @ 3.10GHz (4 cores) >>, OS: I<< GNU/Linux Debian version 8.0 >>, OS kernel: I<< Linux version 3.16.0-4-amd64 >>.
 
 Benchmark with default options (C<< bencher -m DigestSHA1 >>):
 
  #table1#
- +--------------+-----------+-----------+------------+-----------+---------+
- | participant  | rate (/s) | time (ms) | vs_slowest |  errors   | samples |
- +--------------+-----------+-----------+------------+-----------+---------+
- | Digest::SHA1 |       6.6 |     150   |       1    |   0.00049 |       6 |
- | Digest::SHA  |      10   |      99.9 |       1.51 | 4.7e-05   |       6 |
- +--------------+-----------+-----------+------------+-----------+---------+
+ +--------------+-----------+-----------+------------+---------+---------+
+ | participant  | rate (/s) | time (ms) | vs_slowest |  errors | samples |
+ +--------------+-----------+-----------+------------+---------+---------+
+ | Digest::SHA1 |      5.92 |       169 |        1   | 0.00011 |       6 |
+ | Digest::SHA  |      9.8  |       100 |        1.7 | 0.00036 |       6 |
+ +--------------+-----------+-----------+------------+---------+---------+
 
 
 Benchmark module startup overhead (C<< bencher -m DigestSHA1 --module-startup >>):
 
  #table2#
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors | samples |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
- | Digest::SHA         | 0.82                         | 4.2                | 16             |        13 |                      8 |        1   | 2.6e-05 |       6 |
- | Digest::SHA1        | 1.5                          | 5                  | 21             |        10 |                      5 |        1.2 | 5.7e-05 |       7 |
- | perl -e1 (baseline) | 1.2                          | 4.5                | 18             |         5 |                      0 |        2.5 | 2.7e-05 |       7 |
- +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+---------+---------+
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+----------+---------+
+ | participant         | proc_private_dirty_size (MB) | proc_rss_size (MB) | proc_size (MB) | time (ms) | mod_overhead_time (ms) | vs_slowest |  errors  | samples |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+----------+---------+
+ | Digest::SHA         | 0.828                        | 4.2                | 20.1           |      13.8 |                    8.4 |        1   | 1.2e-05  |       6 |
+ | Digest::SHA1        | 1.5                          | 5                  | 25             |      11   |                    5.6 |        1.2 |   0.0001 |       6 |
+ | perl -e1 (baseline) | 1.2                          | 4.6                | 22             |       5.4 |                    0   |        2.5 | 5.4e-05  |       6 |
+ +---------------------+------------------------------+--------------------+----------------+-----------+------------------------+------------+----------+---------+
 
 
 To display as an interactive HTML table on a browser, you can add option C<--format html+datatables>.
